pub struct ClientContent {
pub turns: Option<Vec<Content>>,
pub turn_complete: Option<bool>,
}Expand description
Conversation history or incremental content.
On Gemini 2.5 this can be sent at any time during the session.
On Gemini 3.1 it can only be sent as initial history (before the first
realtimeInput), and requires historyConfig.initialHistoryInClientContent = true.
Fields
turns: Option<Vec<Content>>turn_complete: Option<bool>Trait Implementations
Sourceimpl Clone for ClientContent
impl Clone for ClientContent
Sourcefn clone(&self) -> ClientContent
fn clone(&self) -> ClientContent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ClientContent
impl Debug for ClientContent