pub struct RealtimeInput {
pub audio: Option<Blob>,
pub video: Option<Blob>,
pub text: Option<String>,
pub activity_start: Option<EmptyObject>,
pub activity_end: Option<EmptyObject>,
pub audio_stream_end: Option<bool>,
}Expand description
Streaming real-time input — audio, video, text, or VAD control signals.
Each message should carry only one of these fields.
Audio format
16-bit signed little-endian PCM, recommended 16 kHz sample rate. Chunk size: 100–250 ms (3,200–8,000 bytes raw).
Video format
JPEG or PNG, max 1 fps, recommended < 200 KB per frame.
Fields
audio: Option<Blob>video: Option<Blob>text: Option<String>activity_start: Option<EmptyObject>Manual VAD: signal that user activity has started.
Requires automaticActivityDetection.disabled = true.
activity_end: Option<EmptyObject>Manual VAD: signal that user activity has ended.
audio_stream_end: Option<bool>Auto VAD: notify server that the mic has been muted / stream ended.