pub struct Part {
pub text: Option<String>,
pub inline_data: Option<Blob>,
}Expand description
A single piece of content within a Content turn.
Exactly one field is populated per part on the wire, but we model it with optional fields for forward-compatibility with future part types.
Fields
text: Option<String>inline_data: Option<Blob>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Part
impl<'de> Deserialize<'de> for Part
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl StructuralPartialEq for Part